@@ -614,7 +614,7 @@ void draw_playingarea()
 }
 
 /* callback to add card styles to the hashmap */
-void card_style_add(gpointer key, gpointer value, gpointer box)
+void card_style_add(gpointer key, gpointer value, gpointer *first_style)
 {
 	static int i = 0;
 	GtkComboBox *card_style_box = (GtkComboBox*)glade_xml_get_widget(xml, "card_style");
@@ -627,6 +627,9 @@ void card_style_add(gpointer key, gpointer value, gpointer box)
 		cards_image = cards_image_from_file(value);
 	}
 	
+	if (*first_style == NULL)
+		*first_style = g_string_new(value);
+	
 	i++;
 }
 
@@ -846,6 +849,7 @@ void load_card_styles()
 {
 	DIR *directory = opendir(PACKAGE_DATA_DIR"/pixmaps/gnome-hearts/cards/");
 	struct dirent *file;
+	GString *first_style = NULL;
 
 	game_card_styles = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
@@ -871,7 +875,16 @@ void load_card_styles()
 	}
 	
 	/* loop over he hash table, add all card styles to the combo box and set the active one */
-	g_hash_table_foreach(game_card_styles, card_style_add, NULL);
+	g_hash_table_foreach(game_card_styles, (GHFunc)card_style_add, &first_style);
+	
+	/* Make sure a card style was loaded. If the configured style wasn't found then no style has been loaded
+	   at this point. See Debian bugs 396043 and 395551. */
+	if (cards_image == NULL)
+	{
+		g_assert(first_style != NULL);
+		cards_image = cards_image_from_file(first_style->str);
+		g_string_free(first_style, TRUE);
+	}
 }
 
 /* initialize the background */
@@ -889,6 +902,23 @@ void background_load(gchar* path)
 {
 	background_free(TRUE);
 	background.image = preimage_new_from_file(path);
+	
+	/* If the defined background cannot be loaded, fall back to baize.png */
+	if (!background.image)
+	{
+		background.image = preimage_new_from_file(PACKAGE_DATA_DIR"/pixmaps/gnome-hearts/baize.png");
+		background.tiled = TRUE;
+		game_background_tiled = TRUE;
+		GtkWidget *prefs = glade_xml_get_widget(xml, "background_tile");
+		gtk_toggle_button_set_active((GtkToggleButton*)prefs, TRUE);
+		
+		if (!background.image)
+		{
+			printf("**Error**: The default background could not be loaded.\n");
+			g_assert_not_reached();
+		}
+	}
+	
 	background_set_tiled(background.tiled);
 }
 
@@ -1038,8 +1068,8 @@ int main (int argc, char *argv[])
 
 	/* load the background */
 	background_new();
+	background.tiled = game_background_tiled;
 	background_load(game_background->str);
-	background_set_tiled(game_background_tiled);
 
 	/* autoconnect the glade signals */
 	glade_xml_signal_autoconnect(xml);
